@@ -23,13 +23,14 @@ import functools
 import json
 import pathlib
 import re
-from typing import Any, Callable, Type, Union
+from typing import Any, Callable, Type
 
 import np_logging
 import requests
 
 logger = np_logging.getLogger(__name__)
 
+
 def requester(url: str, *args) -> dict:
     request = url.format(*args)  # .replace(";", "%3B")
     logger.debug(f"Requesting {request}")
@@ -117,11 +118,11 @@ class LIMS2InfoBaseClass(collections.UserDict, abc.ABC):
     def lims_id(self):
         "LIMS2 ID for the object, usually different to the np_id."
         return NotImplemented
-    
+
     @property
     def id(self) -> str | int:
         return self.lims_id
-    
+
     # end of baseclass properties & methods ------------------------------ #
 
 
@@ -248,7 +249,9 @@ class LIMS2SessionInfo(LIMS2InfoBaseClass):
         if not hasattr(self, "_session"):
             _ = self.fetch()  # trigger fetching data from lims
         self.__class__ = (
-            LIMS2EcephysSessionInfo if self._session == "ecephys" else LIMS2BehaviorSessionInfo
+            LIMS2EcephysSessionInfo
+            if self._session == "ecephys"
+            else LIMS2BehaviorSessionInfo
         )
 
 
@@ -302,6 +305,7 @@ def generate_ecephys_session(
         raise ValueError(f"Failed to create session: {decoded_dict}")
     return LIMS2SessionInfo(new_session_id)
 
+
 def generate_hab_session(
     mouse: str | int | LIMS2MouseInfo,
     user: str | LIMS2UserInfo,
@@ -330,7 +334,7 @@ def generate_hab_session(
     return LIMS2SessionInfo(new_session_id)
 
 
-def find_session_folder_string(path: Union[str, pathlib.Path]) -> str | None:
+def find_session_folder_string(path: str | pathlib.Path) -> str | None:
     """Extract [8+digit session ID]_[6-digit mouse ID]_[6-digit date
     str] from a file or folder path"""
     session_reg_exp = r"[0-9]{8,}_[0-9]{6}_[0-9]{8}"
@@ -360,4 +364,4 @@ def info_classes_from_session_folder(
 
 
 if __name__ == "__main__":
-    doctest.testmod()
\ No newline at end of file
+    doctest.testmod()
